==> ejc-probudget-impl-3.0.0-20210910.024505-13-sources.jar: com/ejianc/business/budget/bean/BudgetEntity.java <==
package com.ejianc.business.budget.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.List;
/**
 * 预算管理
 *
 * @author generator
 *
 */
 @TableName("ejc_probudget_budget")
public class BudgetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="base_incomebudget_mny")
    private java.math.BigDecimal baseIncomebudgetMny; // 初始收入预算金额
    @TableField(value="before_incomebudget_mny")
    private java.math.BigDecimal beforeIncomebudgetMny; // 变更前收入预算金额
    @TableField(value="incomebudget_mny")
    private java.math.BigDecimal incomebudgetMny; // 收入预算金额
    @TableField(value="changing_incomebudget_mny")
    private java.math.BigDecimal changingIncomebudgetMny; // 变更中收入预算金额
    @TableField(value="base_costbudget_mny")
    private java.math.BigDecimal baseCostbudgetMny; // 初始成本预算金额
    @TableField(value="before_costbudget_mny")
    private java.math.BigDecimal beforeCostbudgetMny; // 变更前成本预算金额
    @TableField(value="costbudget_mny")
    private java.math.BigDecimal costbudgetMny; // 成本预算金额
    @TableField(value="changing_costbudget_mny")
    private java.math.BigDecimal changingCostbudgetMny; // 变更中成本预算金额
    @TableField(value="base_labor_mny")
    private java.math.BigDecimal baseLaborMny; // 初始人工费
    @TableField(value="before_labor_mny")
    private java.math.BigDecimal beforeLaborMny; // 变更前人工费
    @TableField(value="labor_mny")
    private java.math.BigDecimal laborMny; // 人工费
    @TableField(value="changing_labor_mny")
    private java.math.BigDecimal changingLaborMny; // 变更中人工费
    @TableField(value="base_material_mny")
    private java.math.BigDecimal baseMaterialMny; // 初始材料费
    @TableField(value="before_material_mny")
    private java.math.BigDecimal beforeMaterialMny; // 变更前材料费
    @TableField(value="material_mny")
    private java.math.BigDecimal materialMny; // 材料费
    @TableField(value="changing_material_mny")
    private java.math.BigDecimal changingMaterialMny; // 变更中材料费
    @TableField(value="base_manage_rate")
    private java.math.BigDecimal baseManageRate; // 初始管理费率
    @TableField(value="before_manage_rate")
    private java.math.BigDecimal beforeManageRate; // 变更前管理费率
    @TableField(value="manage_rate")
    private java.math.BigDecimal manageRate; // 管理费率
    @TableField(value="changing_manage_rate")
    private java.math.BigDecimal changingManageRate; // 变更中管理费率
    @TableField(value="base_manage_mny")
    private java.math.BigDecimal baseManageMny; // 初始管理费
    @TableField(value="before_manage_mny")
    private java.math.BigDecimal beforeManageMny; // 变更前管理费
    @TableField(value="manage_mny")
    private java.math.BigDecimal manageMny; // 管理费
    @TableField(value="changing_manage_mny")
    private java.math.BigDecimal changingManageMny; // 变更中管理费
    @TableField(value="base_incomebudget_adjust_mny")
    private java.math.BigDecimal baseIncomebudgetAdjustMny; // 初始收入预算调整金额
    @TableField(value="before_incomebudget_adjust_mny")
    private java.math.BigDecimal beforeIncomebudgetAdjustMny; // 变更前收入预算调整金额
    @TableField(value="incomebudget_adjust_mny")
    private java.math.BigDecimal incomebudgetAdjustMny; // 收入预算调整金额
    @TableField(value="changing_incomebudget_adjust_mny")
    private java.math.BigDecimal changingIncomebudgetAdjustMny; // 变更中收入预算调整金额
    @TableField(value="memo")
    private String memo; // 分包内容
    @TableField(value="change_code")
    private String changeCode; // 变更单号
    @TableField(value="change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="change_status")
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="area")
    private String area; //所属区域


    @TableField(exist=false)
    @SubEntity(serviceName="budgetDetailService", pidName = "budgetId")
    private List<BudgetDetailEntity> detailList = new ArrayList<>(); // 预算管理明细


    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 初始收入预算金额
     */
    public java.math.BigDecimal getBaseIncomebudgetMny() {
        return baseIncomebudgetMny;
    }

    /**
     * 初始收入预算金额
     */
    public void setBaseIncomebudgetMny(java.math.BigDecimal baseIncomebudgetMny) {
        this.baseIncomebudgetMny = baseIncomebudgetMny;
    }
    /**
     * 变更前收入预算金额
     */
    public java.math.BigDecimal getBeforeIncomebudgetMny() {
        return beforeIncomebudgetMny;
    }

    /**
     * 变更前收入预算金额
     */
    public void setBeforeIncomebudgetMny(java.math.BigDecimal beforeIncomebudgetMny) {
        this.beforeIncomebudgetMny = beforeIncomebudgetMny;
    }
    /**
     * 收入预算金额
     */
    public java.math.BigDecimal getIncomebudgetMny() {
        return incomebudgetMny;
    }

    /**
     * 收入预算金额
     */
    public void setIncomebudgetMny(java.math.BigDecimal incomebudgetMny) {
        this.incomebudgetMny = incomebudgetMny;
    }
    /**
     * 变更中收入预算金额
     */
    public java.math.BigDecimal getChangingIncomebudgetMny() {
        return changingIncomebudgetMny;
    }

    /**
     * 变更中收入预算金额
     */
    public void setChangingIncomebudgetMny(java.math.BigDecimal changingIncomebudgetMny) {
        this.changingIncomebudgetMny = changingIncomebudgetMny;
    }
    /**
     * 初始成本预算金额
     */
    public java.math.BigDecimal getBaseCostbudgetMny() {
        return baseCostbudgetMny;
    }

    /**
     * 初始成本预算金额
     */
    public void setBaseCostbudgetMny(java.math.BigDecimal baseCostbudgetMny) {
        this.baseCostbudgetMny = baseCostbudgetMny;
    }
    /**
     * 变更前成本预算金额
     */
    public java.math.BigDecimal getBeforeCostbudgetMny() {
        return beforeCostbudgetMny;
    }

    /**
     * 变更前成本预算金额
     */
    public void setBeforeCostbudgetMny(java.math.BigDecimal beforeCostbudgetMny) {
        this.beforeCostbudgetMny = beforeCostbudgetMny;
    }
    /**
     * 成本预算金额
     */
    public java.math.BigDecimal getCostbudgetMny() {
        return costbudgetMny;
    }

    /**
     * 成本预算金额
     */
    public void setCostbudgetMny(java.math.BigDecimal costbudgetMny) {
        this.costbudgetMny = costbudgetMny;
    }
    /**
     * 变更中成本预算金额
     */
    public java.math.BigDecimal getChangingCostbudgetMny() {
        return changingCostbudgetMny;
    }

    /**
     * 变更中成本预算金额
     */
    public void setChangingCostbudgetMny(java.math.BigDecimal changingCostbudgetMny) {
        this.changingCostbudgetMny = changingCostbudgetMny;
    }
    /**
     * 初始人工费
     */
    public java.math.BigDecimal getBaseLaborMny() {
        return baseLaborMny;
    }

    /**
     * 初始人工费
     */
    public void setBaseLaborMny(java.math.BigDecimal baseLaborMny) {
        this.baseLaborMny = baseLaborMny;
    }
    /**
     * 变更前人工费
     */
    public java.math.BigDecimal getBeforeLaborMny() {
        return beforeLaborMny;
    }

    /**
     * 变更前人工费
     */
    public void setBeforeLaborMny(java.math.BigDecimal beforeLaborMny) {
        this.beforeLaborMny = beforeLaborMny;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLaborMny() {
        return laborMny;
    }

    /**
     * 人工费
     */
    public void setLaborMny(java.math.BigDecimal laborMny) {
        this.laborMny = laborMny;
    }
    /**
     * 变更中人工费
     */
    public java.math.BigDecimal getChangingLaborMny() {
        return changingLaborMny;
    }

    /**
     * 变更中人工费
     */
    public void setChangingLaborMny(java.math.BigDecimal changingLaborMny) {
        this.changingLaborMny = changingLaborMny;
    }
    /**
     * 初始材料费
     */
    public java.math.BigDecimal getBaseMaterialMny() {
        return baseMaterialMny;
    }

    /**
     * 初始材料费
     */
    public void setBaseMaterialMny(java.math.BigDecimal baseMaterialMny) {
        this.baseMaterialMny = baseMaterialMny;
    }
    /**
     * 变更前材料费
     */
    public java.math.BigDecimal getBeforeMaterialMny() {
        return beforeMaterialMny;
    }

    /**
     * 变更前材料费
     */
    public void setBeforeMaterialMny(java.math.BigDecimal beforeMaterialMny) {
        this.beforeMaterialMny = beforeMaterialMny;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialMny() {
        return materialMny;
    }

    /**
     * 材料费
     */
    public void setMaterialMny(java.math.BigDecimal materialMny) {
        this.materialMny = materialMny;
    }
    /**
     * 变更中材料费
     */
    public java.math.BigDecimal getChangingMaterialMny() {
        return changingMaterialMny;
    }

    /**
     * 变更中材料费
     */
    public void setChangingMaterialMny(java.math.BigDecimal changingMaterialMny) {
        this.changingMaterialMny = changingMaterialMny;
    }
    /**
     * 初始管理费率
     */
    public java.math.BigDecimal getBaseManageRate() {
        return baseManageRate;
    }

    /**
     * 初始管理费率
     */
    public void setBaseManageRate(java.math.BigDecimal baseManageRate) {
        this.baseManageRate = baseManageRate;
    }
    /**
     * 变更前管理费率
     */
    public java.math.BigDecimal getBeforeManageRate() {
        return beforeManageRate;
    }

    /**
     * 变更前管理费率
     */
    public void setBeforeManageRate(java.math.BigDecimal beforeManageRate) {
        this.beforeManageRate = beforeManageRate;
    }
    /**
     * 管理费率
     */
    public java.math.BigDecimal getManageRate() {
        return manageRate;
    }

    /**
     * 管理费率
     */
    public void setManageRate(java.math.BigDecimal manageRate) {
        this.manageRate = manageRate;
    }
    /**
     * 变更中管理费率
     */
    public java.math.BigDecimal getChangingManageRate() {
        return changingManageRate;
    }

    /**
     * 变更中管理费率
     */
    public void setChangingManageRate(java.math.BigDecimal changingManageRate) {
        this.changingManageRate = changingManageRate;
    }
    /**
     * 初始管理费
     */
    public java.math.BigDecimal getBaseManageMny() {
        return baseManageMny;
    }

    /**
     * 初始管理费
     */
    public void setBaseManageMny(java.math.BigDecimal baseManageMny) {
        this.baseManageMny = baseManageMny;
    }
    /**
     * 变更前管理费
     */
    public java.math.BigDecimal getBeforeManageMny() {
        return beforeManageMny;
    }

    /**
     * 变更前管理费
     */
    public void setBeforeManageMny(java.math.BigDecimal beforeManageMny) {
        this.beforeManageMny = beforeManageMny;
    }
    /**
     * 管理费
     */
    public java.math.BigDecimal getManageMny() {
        return manageMny;
    }

    /**
     * 管理费
     */
    public void setManageMny(java.math.BigDecimal manageMny) {
        this.manageMny = manageMny;
    }
    /**
     * 变更中管理费
     */
    public java.math.BigDecimal getChangingManageMny() {
        return changingManageMny;
    }

    /**
     * 变更中管理费
     */
    public void setChangingManageMny(java.math.BigDecimal changingManageMny) {
        this.changingManageMny = changingManageMny;
    }
    /**
     * 初始收入预算调整金额
     */
    public java.math.BigDecimal getBaseIncomebudgetAdjustMny() {
        return baseIncomebudgetAdjustMny;
    }

    /**
     * 初始收入预算调整金额
     */
    public void setBaseIncomebudgetAdjustMny(java.math.BigDecimal baseIncomebudgetAdjustMny) {
        this.baseIncomebudgetAdjustMny = baseIncomebudgetAdjustMny;
    }
    /**
     * 变更前收入预算调整金额
     */
    public java.math.BigDecimal getBeforeIncomebudgetAdjustMny() {
        return beforeIncomebudgetAdjustMny;
    }

    /**
     * 变更前收入预算调整金额
     */
    public void setBeforeIncomebudgetAdjustMny(java.math.BigDecimal beforeIncomebudgetAdjustMny) {
        this.beforeIncomebudgetAdjustMny = beforeIncomebudgetAdjustMny;
    }
    /**
     * 收入预算调整金额
     */
    public java.math.BigDecimal getIncomebudgetAdjustMny() {
        return incomebudgetAdjustMny;
    }

    /**
     * 收入预算调整金额
     */
    public void setIncomebudgetAdjustMny(java.math.BigDecimal incomebudgetAdjustMny) {
        this.incomebudgetAdjustMny = incomebudgetAdjustMny;
    }
    /**
     * 变更中收入预算调整金额
     */
    public java.math.BigDecimal getChangingIncomebudgetAdjustMny() {
        return changingIncomebudgetAdjustMny;
    }

    /**
     * 变更中收入预算调整金额
     */
    public void setChangingIncomebudgetAdjustMny(java.math.BigDecimal changingIncomebudgetAdjustMny) {
        this.changingIncomebudgetAdjustMny = changingIncomebudgetAdjustMny;
    }
    /**
     * 分包内容
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 分包内容
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 变更单号
     */
    public String getChangeCode() {
        return changeCode;
    }

    /**
     * 变更单号
     */
    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    /**
     * 变更版本
     */
    public Integer getChangeVersion() {
        return changeVersion;
    }

    /**
     * 变更版本
     */
    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    /**
     * 变更主键
     */
    public Long getChangeId() {
        return changeId;
    }

    /**
     * 变更主键
     */
    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态(1-未变更 2-变更中 3-已变更)
     */
    public Integer getChangeStatus() {
        return changeStatus;
    }

    /**
     * 变更状态(1-未变更 2-变更中 3-已变更)
     */
    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }

    /**
     * 预算管理明细
     */
    public List<BudgetDetailEntity> getDetailList() {
        return detailList;
    }

    /**
     * 预算管理明细
     */
    public void setDetailList(List<BudgetDetailEntity> detailList) {
        this.detailList = detailList;
    }
}

==> ejc-probudget-impl-3.0.0-20210919.021332-47-sources.jar: com/ejianc/business/budget/bean/BudgetEntity.java <==
package com.ejianc.business.budget.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
/**
 * 预算管理
 *
 * @author generator
 *
 */
 @TableName("ejc_probudget_budget")
public class BudgetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="base_incomebudget_mny")
    private BigDecimal baseIncomebudgetMny; // 初始收入预算金额
    @TableField(value="before_incomebudget_mny")
    private BigDecimal beforeIncomebudgetMny; // 变更前收入预算金额
    @TableField(value="incomebudget_mny")
    private BigDecimal incomebudgetMny; // 收入预算金额
    @TableField(value="changing_incomebudget_mny")
    private BigDecimal changingIncomebudgetMny; // 变更中收入预算金额
    @TableField(value="base_costbudget_mny")
    private BigDecimal baseCostbudgetMny; // 初始成本预算金额
    @TableField(value="before_costbudget_mny")
    private BigDecimal beforeCostbudgetMny; // 变更前成本预算金额
    @TableField(value="costbudget_mny")
    private BigDecimal costbudgetMny; // 成本预算金额
    @TableField(value="changing_costbudget_mny")
    private BigDecimal changingCostbudgetMny; // 变更中成本预算金额
    @TableField(value="base_labor_mny")
    private BigDecimal baseLaborMny; // 初始人工费
    @TableField(value="before_labor_mny")
    private BigDecimal beforeLaborMny; // 变更前人工费
    @TableField(value="labor_mny")
    private BigDecimal laborMny; // 人工费
    @TableField(value="changing_labor_mny")
    private BigDecimal changingLaborMny; // 变更中人工费
    @TableField(value="base_material_mny")
    private BigDecimal baseMaterialMny; // 初始材料费
    @TableField(value="before_material_mny")
    private BigDecimal beforeMaterialMny; // 变更前材料费
    @TableField(value="material_mny")
    private BigDecimal materialMny; // 材料费
    @TableField(value="changing_material_mny")
    private BigDecimal changingMaterialMny; // 变更中材料费
    @TableField(value="base_manage_rate")
    private BigDecimal baseManageRate; // 初始管理费率
    @TableField(value="before_manage_rate")
    private BigDecimal beforeManageRate; // 变更前管理费率
    @TableField(value="manage_rate")
    private BigDecimal manageRate; // 管理费率
    @TableField(value="changing_manage_rate")
    private BigDecimal changingManageRate; // 变更中管理费率
    @TableField(value="base_manage_mny")
    private BigDecimal baseManageMny; // 初始管理费
    @TableField(value="before_manage_mny")
    private BigDecimal beforeManageMny; // 变更前管理费
    @TableField(value="manage_mny")
    private BigDecimal manageMny; // 管理费
    @TableField(value="changing_manage_mny")
    private BigDecimal changingManageMny; // 变更中管理费
    @TableField(value="base_incomebudget_adjust_mny")
    private BigDecimal baseIncomebudgetAdjustMny; // 初始收入预算调整金额
    @TableField(value="before_incomebudget_adjust_mny")
    private BigDecimal beforeIncomebudgetAdjustMny; // 变更前收入预算调整金额
    @TableField(value="incomebudget_adjust_mny")
    private BigDecimal incomebudgetAdjustMny; // 收入预算调整金额
    @TableField(value="changing_incomebudget_adjust_mny")
    private BigDecimal changingIncomebudgetAdjustMny; // 变更中收入预算调整金额
    @TableField(value="memo")
    private String memo; // 分包内容
    @TableField(value="change_code")
    private String changeCode; // 变更单号
    @TableField(value="change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="change_status")
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="area")
    private String area; //所属区域


    @TableField(exist=false)
    @SubEntity(serviceName="budgetDetailService", pidName = "budgetId")
    private List<BudgetDetailEntity> detailList = new ArrayList<>(); // 预算管理明细


    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 初始收入预算金额
     */
    public BigDecimal getBaseIncomebudgetMny() {
        return baseIncomebudgetMny;
    }

    /**
     * 初始收入预算金额
     */
    public void setBaseIncomebudgetMny(BigDecimal baseIncomebudgetMny) {
        this.baseIncomebudgetMny = baseIncomebudgetMny;
    }
    /**
     * 变更前收入预算金额
     */
    public BigDecimal getBeforeIncomebudgetMny() {
        return beforeIncomebudgetMny;
    }

    /**
     * 变更前收入预算金额
     */
    public void setBeforeIncomebudgetMny(BigDecimal beforeIncomebudgetMny) {
        this.beforeIncomebudgetMny = beforeIncomebudgetMny;
    }
    /**
     * 收入预算金额
     */
    public BigDecimal getIncomebudgetMny() {
        return incomebudgetMny;
    }

    /**
     * 收入预算金额
     */
    public void setIncomebudgetMny(BigDecimal incomebudgetMny) {
        this.incomebudgetMny = incomebudgetMny;
    }
    /**
     * 变更中收入预算金额
     */
    public BigDecimal getChangingIncomebudgetMny() {
        return changingIncomebudgetMny;
    }

    /**
     * 变更中收入预算金额
     */
    public void setChangingIncomebudgetMny(BigDecimal changingIncomebudgetMny) {
        this.changingIncomebudgetMny = changingIncomebudgetMny;
    }
    /**
     * 初始成本预算金额
     */
    public BigDecimal getBaseCostbudgetMny() {
        return baseCostbudgetMny;
    }

    /**
     * 初始成本预算金额
     */
    public void setBaseCostbudgetMny(BigDecimal baseCostbudgetMny) {
        this.baseCostbudgetMny = baseCostbudgetMny;
    }
    /**
     * 变更前成本预算金额
     */
    public BigDecimal getBeforeCostbudgetMny() {
        return beforeCostbudgetMny;
    }

    /**
     * 变更前成本预算金额
     */
    public void setBeforeCostbudgetMny(BigDecimal beforeCostbudgetMny) {
        this.beforeCostbudgetMny = beforeCostbudgetMny;
    }
    /**
     * 成本预算金额
     */
    public BigDecimal getCostbudgetMny() {
        return costbudgetMny;
    }

    /**
     * 成本预算金额
     */
    public void setCostbudgetMny(BigDecimal costbudgetMny) {
        this.costbudgetMny = costbudgetMny;
    }
    /**
     * 变更中成本预算金额
     */
    public BigDecimal getChangingCostbudgetMny() {
        return changingCostbudgetMny;
    }

    /**
     * 变更中成本预算金额
     */
    public void setChangingCostbudgetMny(BigDecimal changingCostbudgetMny) {
        this.changingCostbudgetMny = changingCostbudgetMny;
    }
    /**
     * 初始人工费
     */
    public BigDecimal getBaseLaborMny() {
        return baseLaborMny;
    }

    /**
     * 初始人工费
     */
    public void setBaseLaborMny(BigDecimal baseLaborMny) {
        this.baseLaborMny = baseLaborMny;
    }
    /**
     * 变更前人工费
     */
    public BigDecimal getBeforeLaborMny() {
        return beforeLaborMny;
    }

    /**
     * 变更前人工费
     */
    public void setBeforeLaborMny(BigDecimal beforeLaborMny) {
        this.beforeLaborMny = beforeLaborMny;
    }
    /**
     * 人工费
     */
    public BigDecimal getLaborMny() {
        return laborMny;
    }

    /**
     * 人工费
     */
    public void setLaborMny(BigDecimal laborMny) {
        this.laborMny = laborMny;
    }
    /**
     * 变更中人工费
     */
    public BigDecimal getChangingLaborMny() {
        return changingLaborMny;
    }

    /**
     * 变更中人工费
     */
    public void setChangingLaborMny(BigDecimal changingLaborMny) {
        this.changingLaborMny = changingLaborMny;
    }
    /**
     * 初始材料费
     */
    public BigDecimal getBaseMaterialMny() {
        return baseMaterialMny;
    }

    /**
     * 初始材料费
     */
    public void setBaseMaterialMny(BigDecimal baseMaterialMny) {
        this.baseMaterialMny = baseMaterialMny;
    }
    /**
     * 变更前材料费
     */
    public BigDecimal getBeforeMaterialMny() {
        return beforeMaterialMny;
    }

    /**
     * 变更前材料费
     */
    public void setBeforeMaterialMny(BigDecimal beforeMaterialMny) {
        this.beforeMaterialMny = beforeMaterialMny;
    }
    /**
     * 材料费
     */
    public BigDecimal getMaterialMny() {
        return materialMny;
    }

    /**
     * 材料费
     */
    public void setMaterialMny(BigDecimal materialMny) {
        this.materialMny = materialMny;
    }
    /**
     * 变更中材料费
     */
    public BigDecimal getChangingMaterialMny() {
        return changingMaterialMny;
    }

    /**
     * 变更中材料费
     */
    public void setChangingMaterialMny(BigDecimal changingMaterialMny) {
        this.changingMaterialMny = changingMaterialMny;
    }
    /**
     * 初始管理费率
     */
    public BigDecimal getBaseManageRate() {
        return baseManageRate;
    }

    /**
     * 初始管理费率
     */
    public void setBaseManageRate(BigDecimal baseManageRate) {
        this.baseManageRate = baseManageRate;
    }
    /**
     * 变更前管理费率
     */
    public BigDecimal getBeforeManageRate() {
        return beforeManageRate;
    }

    /**
     * 变更前管理费率
     */
    public void setBeforeManageRate(BigDecimal beforeManageRate) {
        this.beforeManageRate = beforeManageRate;
    }
    /**
     * 管理费率
     */
    public BigDecimal getManageRate() {
        return manageRate;
    }

    /**
     * 管理费率
     */
    public void setManageRate(BigDecimal manageRate) {
        this.manageRate = manageRate;
    }
    /**
     * 变更中管理费率
     */
    public BigDecimal getChangingManageRate() {
        return changingManageRate;
    }

    /**
     * 变更中管理费率
     */
    public void setChangingManageRate(BigDecimal changingManageRate) {
        this.changingManageRate = changingManageRate;
    }
    /**
     * 初始管理费
     */
    public BigDecimal getBaseManageMny() {
        return baseManageMny;
    }

    /**
     * 初始管理费
     */
    public void setBaseManageMny(BigDecimal baseManageMny) {
        this.baseManageMny = baseManageMny;
    }
    /**
     * 变更前管理费
     */
    public BigDecimal getBeforeManageMny() {
        return beforeManageMny;
    }

    /**
     * 变更前管理费
     */
    public void setBeforeManageMny(BigDecimal beforeManageMny) {
        this.beforeManageMny = beforeManageMny;
    }
    /**
     * 管理费
     */
    public BigDecimal getManageMny() {
        return manageMny;
    }

    /**
     * 管理费
     */
    public void setManageMny(BigDecimal manageMny) {
        this.manageMny = manageMny;
    }
    /**
     * 变更中管理费
     */
    public BigDecimal getChangingManageMny() {
        return changingManageMny;
    }

    /**
     * 变更中管理费
     */
    public void setChangingManageMny(BigDecimal changingManageMny) {
        this.changingManageMny = changingManageMny;
    }
    /**
     * 初始收入预算调整金额
     */
    public BigDecimal getBaseIncomebudgetAdjustMny() {
        return baseIncomebudgetAdjustMny;
    }

    /**
     * 初始收入预算调整金额
     */
    public void setBaseIncomebudgetAdjustMny(BigDecimal baseIncomebudgetAdjustMny) {
        this.baseIncomebudgetAdjustMny = baseIncomebudgetAdjustMny;
    }
    /**
     * 变更前收入预算调整金额
     */
    public BigDecimal getBeforeIncomebudgetAdjustMny() {
        return beforeIncomebudgetAdjustMny;
    }

    /**
     * 变更前收入预算调整金额
     */
    public void setBeforeIncomebudgetAdjustMny(BigDecimal beforeIncomebudgetAdjustMny) {
        this.beforeIncomebudgetAdjustMny = beforeIncomebudgetAdjustMny;
    }
    /**
     * 收入预算调整金额
     */
    public BigDecimal getIncomebudgetAdjustMny() {
        return incomebudgetAdjustMny;
    }

    /**
     * 收入预算调整金额
     */
    public void setIncomebudgetAdjustMny(BigDecimal incomebudgetAdjustMny) {
        this.incomebudgetAdjustMny = incomebudgetAdjustMny;
    }
    /**
     * 变更中收入预算调整金额
     */
    public BigDecimal getChangingIncomebudgetAdjustMny() {
        return changingIncomebudgetAdjustMny;
    }

    /**
     * 变更中收入预算调整金额
     */
    public void setChangingIncomebudgetAdjustMny(BigDecimal changingIncomebudgetAdjustMny) {
        this.changingIncomebudgetAdjustMny = changingIncomebudgetAdjustMny;
    }
    /**
     * 分包内容
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 分包内容
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 变更单号
     */
    public String getChangeCode() {
        return changeCode;
    }

    /**
     * 变更单号
     */
    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    /**
     * 变更版本
     */
    public Integer getChangeVersion() {
        return changeVersion;
    }

    /**
     * 变更版本
     */
    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    /**
     * 变更主键
     */
    public Long getChangeId() {
        return changeId;
    }

    /**
     * 变更主键
     */
    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态(1-未变更 2-变更中 3-已变更)
     */
    public Integer getChangeStatus() {
        return changeStatus;
    }

    /**
     * 变更状态(1-未变更 2-变更中 3-已变更)
     */
    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }

    /**
     * 预算管理明细
     */
    public List<BudgetDetailEntity> getDetailList() {
        return detailList;
    }

    /**
     * 预算管理明细
     */
    public void setDetailList(List<BudgetDetailEntity> detailList) {
        this.detailList = detailList;
    }
}
